@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: aboutdlg.h,v 1.1 2009/07/05 21:14:56 robertl Exp $
+// $Id: aboutdlg.h,v 1.1 2009-07-05 21:14:56 robertl Exp $
 //------------------------------------------------------------------------
 //
 //  Copyright (C) 2009  S. Khai Mong <khai@mangrai.com>.
@@ -30,10 +30,10 @@
 class AboutDlg: public QDialog {
  public:
   AboutDlg(QWidget *parent,  const QString &ver1,
-	   const QString &ver2);
+     const QString &ver2, const QString &installationId);
 
  private:
-  Ui_AboutDlg  ui;
+  Ui_AboutDlg  ui_;
 
 };
 
