@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2002 Robert Lipe, robertlipe@usa.net
+    Copyright (C) 2002-2005 Robert Lipe, robertlipe@usa.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,28 +24,31 @@
  * (Donations welcome. :-)
  */
 typedef enum {
-	mm_unknown = 0 ,
-	mm_gps315320,
-	mm_map410,
-	mm_map330,
-	mm_gps310,
-	mm_meridian,
-	mm_sportrak
+  mm_unknown = 0 ,
+  mm_gps315320,
+  mm_map410,
+  mm_map330,
+  mm_gps310,
+  mm_meridian,
+  mm_sportrak
 } meridian_model;
 
 typedef struct pid_to_model {
-	meridian_model model;
-	int pid;
-	const char *model_n;
+  meridian_model model;
+  int pid;
+  const char* model_n;
 } pid_to_model_t;
 
 typedef struct icon_mapping {
-	const char *token;
-	const char *icon;
+  const char* token;
+  const char* icon;
 } icon_mapping_t;
 
-const char * mag_find_descr_from_token(const char *token);
-const char * mag_find_token_from_descr(const char *icon);
+QString mag_find_descr_from_token(const char* token);
+QString mag_find_token_from_descr(const QString& icon);
 
-waypoint * mag_trkparse(char *trkmsg);
-void mag_rteparse(char *rtemsg);
+unsigned int mag_checksum(const char* const buf);
+QString m330_cleanse(const char* istring);
+
+Waypoint* mag_trkparse(char* trkmsg);
+void mag_rteparse(char* rtemsg);
