@@ -1,4 +1,6 @@
-#define HAVE_LIBEXPAT 1
+#if 0
+//This file is no longer used, the defines are set in the project files
+
 #define __va_copy(ap1, ap2) ((ap1) = (ap2))
 
 // This controls the capabilities of our Character Encoding Transformations.
@@ -7,22 +9,23 @@
 // Define to one for everything we know.
 
 /* 0 for most-used, 1 for all character sets */
-#undef CET_WANTED     
+#define CET_WANTED 1
 
 /* 1 to enable as many formats as possible */
-#undef MAXIMAL_ENABLED
+#define MAXIMAL_ENABLED 1
 
 /* 1 to enable the CSV formats support */
-#undef CSVFMTS_ENABLED 
+#define CSVFMTS_ENABLED 1
 
 /* 1 to enable all the filters. */
-#undef FILTERS_ENABLED 
+#define FILTERS_ENABLED 1
 
 /* 1 to enable Palm PDB support */
-#undef  PDBFMTS_ENABLED 
+#define PDBFMTS_ENABLED 1
 
 /* 1 to enable shapefile support */
-#undef SHAPELIB_ENABLED
+#define SHAPELIB_ENABLED 1
 
 /* 1 to inhibit our use of zlib. */
-#define ZLIB_INHIBITED 1
+#undef ZLIB_INHIBITED
+#endif
